Core Data Structures
====================

.. module:: hbat.core.structure

Molecular structure classes for HBAT.

This module contains the core data structures representing molecular entities
including atoms, bonds, and residues from PDB files.

Classes
-------

.. autoclass:: Bond
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: Atom
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: Residue
   :members:
   :undoc-members:
   :show-inheritance: